



if not exist %LIBRARY_INC%\\CL exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_INC%\\CL\\cl.hpp exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_INC%\\CL\\cl2.hpp exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
